@@ -346,8 +346,10 @@ class PPOAgent(AgentBase):
     @staticmethod
     def from_state(state: AgentState) -> AgentBase:
         agent = PPOAgent(state.state_space, state.action_space, **state.config)
-        agent.set_network(state.network)
-        agent.set_buffer(state.buffer)
+        if state.network is not None:
+            agent.set_network(state.network)
+        if state.buffer is not None:
+            agent.set_buffer(state.buffer)
         return agent
 
     def save_state(self, path: str):
